@@ -3,7 +3,7 @@ package Net::DNS::RR;
 use strict;
 use warnings;
 
-our $VERSION = (qw$Id: RR.pm 2003 2025-01-21 12:06:06Z willem $)[2];
+our $VERSION = (qw$Id: RR.pm 2035 2025-08-14 11:49:15Z willem $)[2];
 
 
 =head1 NAME
@@ -174,20 +174,24 @@ my @core = qw(owner name type class ttl rdlength);
 sub _new_hash {
 	my $base = shift;
 
-	my %attribute = ( owner => '.', type => 'NULL' );
+	my %argument = ( owner => '.', type => 'NULL' );
+	my @attribute;
 	while ( my $key = shift ) {
-		$attribute{lc $key} = shift;
+		push @attribute, $key;
+		$argument{lc $key} = shift;
 	}
 
-	my ( $owner, $name, $type, $class, $ttl ) = delete @attribute{@core};
+	my ( $owner, $name, $type, $class, $ttl ) = delete @argument{@core};
 
-	my $self = $base->_subclass( $type, scalar(%attribute) );
+	my $self = $base->_subclass( $type, scalar(%argument) );
 	$self->owner( $name ? $name : $owner );
 	$self->class($class) if defined $class;			# optional CLASS
 	$self->ttl($ttl)     if defined $ttl;			# optional TTL
 
 	eval {
-		while ( my ( $attribute, $value ) = each %attribute ) {
+		foreach my $attribute (@attribute) {
+			my $value = $argument{lc $attribute};
+			next unless defined $value;
 			$self->$attribute( ref($value) eq 'ARRAY' ? @$value : $value );
 		}
 	};
@@ -322,23 +326,24 @@ This differs from RR attribute methods, which omit the trailing dot.
 sub string {
 	my $self = shift;
 
-	my $name = $self->{owner}->string;
-	my @ttl	 = grep {defined} $self->{ttl};
-	my @core = ( $name, @ttl, $self->class, $self->type );
+	my $owner = $self->{owner}->string;
+	my @ttl	  = defined $self->{ttl}   ? $self->{ttl} : ();
+	my @class = defined $self->{class} ? $self->class : ();
+	my @core  = ( $owner, @ttl, @class, $self->type );
 
 	local $SIG{__DIE__};
 	my $empty = $self->_empty;
 	my @rdata = $empty ? () : eval { $self->_format_rdata };
 	carp $@ if $@;
 
-	my $tab	 = length($name) < 72 ? "\t" : ' ';
+	my $tab	 = length($owner) < 72 ? "\t" : ' ';
 	my @line = _wrap( join( $tab, @core, '(' ), @rdata, ')' );
 
 	my $last = pop(@line);					# last or only line
 	$last = join $tab, @core, "@rdata" unless scalar(@line);
 
 	$self->_annotation('no data') if $empty;
-	return join "\n\t", @line, _wrap( $last, map {"; $_"} $self->_annotation );
+	return join "\n\t", @line, _wrap( $last, $self->_annotation );
 }
 
 
@@ -368,8 +373,9 @@ Returns a token list representation of the RR zone file string.
 sub token {
 	my $self = shift;
 
-	my @ttl	 = grep {defined} $self->{ttl};
-	my @core = ( $self->{owner}->string, @ttl, $self->class, $self->type );
+	my @ttl	  = defined $self->{ttl}   ? $self->{ttl} : ();
+	my @class = defined $self->{class} ? $self->class : ();
+	my @core  = ( $self->{owner}->string, @ttl, @class, $self->type );
 
 	# parse into quoted strings, contiguous non-whitespace and (discarded) comments
 	local $_ = $self->_empty ? '' : join( ' ', $self->_format_rdata );
@@ -395,8 +401,8 @@ and provisioning software.
 sub generic {
 	my $self = shift;
 
-	my @ttl	  = grep {defined} $self->{ttl};
-	my @class = map	 {"CLASS$_"} grep {defined} $self->{class};
+	my @ttl	  = defined $self->{ttl}   ? $self->{ttl}	   : ();
+	my @class = defined $self->{class} ? "CLASS$self->{class}" : ();
 	my @core  = ( $self->{owner}->string, @ttl, @class, "TYPE$self->{type}" );
 	my $data  = $self->rdata;
 	my @data  = ( '\\#', length($data), split /(\S{32})/, unpack 'H*', $data );
@@ -715,8 +721,8 @@ sub _subclass {
 
 sub _annotation {
 	my ( $self, @note ) = @_;
-	$self->{annotation} = ["@note"] if scalar @note;
-	return wantarray ? @{$self->{annotation} || []} : ();
+	push @{$self->{annotation}}, "; @note", "\n" if scalar @note;
+	return wantarray ? @{delete( $self->{annotation} ) || []} : undef;
 }
 
 
@@ -769,12 +775,10 @@ sub AUTOLOAD {				## Default method
 	our $AUTOLOAD;
 	my ($method) = reverse split /::/, $AUTOLOAD;
 
-	for ( my $action = $method ) {	## tolerate mixed-case attribute name
-		tr [A-Z-] [a-z_];
-		if ( $self->can($action) ) {
-			*{$AUTOLOAD} = sub { shift->$action(@_) };
-			return &$AUTOLOAD;
-		}
+	my $canonical = lc($method);	## tolerate mixed-case attribute name
+	if ( $self->can($canonical) ) {
+		*{$AUTOLOAD} = sub { shift->$canonical(@_) };
+		return &$AUTOLOAD;
 	}
 
 	my $oref = ref($self);
@@ -786,7 +790,7 @@ sub AUTOLOAD {				## Default method
 	my $module = join '::', __PACKAGE__, $self->type;
 	eval("require $module") if $oref eq __PACKAGE__;	## no critic ProhibitStringyEval
 
-	@_ = ( <<"END" );
+	@_ = (<<"END");
 ***  FATAL PROGRAM ERROR!!	Unknown instance method "$method"
 ***  which the program has attempted to call for the object:
 ***
