@@ -1,76 +1,77 @@
 package Net::DNS::RR::LOC;
 
-#
-# $Id: LOC.pm 1388 2015-09-07 12:28:16Z willem $
-#
-use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1388 $)[1];
-
-
 use strict;
+use warnings;
+our $VERSION = (qw$Id: LOC.pm 2003 2025-01-21 12:06:06Z willem $)[2];
+
 use base qw(Net::DNS::RR);
 
+
 =head1 NAME
 
 Net::DNS::RR::LOC - DNS LOC resource record
 
 =cut
 
-
 use integer;
 
 use Carp;
 
 
 sub _decode_rdata {			## decode rdata from wire-format octet string
-	my $self = shift;
-	my ( $data, $offset ) = @_;
+	my ( $self, $data, $offset ) = @_;
 
 	my $version = $self->{version} = unpack "\@$offset C", $$data;
 	@{$self}{qw(size hp vp latitude longitude altitude)} = unpack "\@$offset xC3N3", $$data;
+	return;
 }
 
 
 sub _encode_rdata {			## encode rdata as wire-format octet string
 	my $self = shift;
 
-	return '' unless defined $self->{longitude};
-	pack 'C4N3', @{$self}{qw(version size hp vp latitude longitude altitude)};
+	return pack 'C4N3', @{$self}{qw(version size hp vp latitude longitude altitude)};
 }
 
 
 sub _format_rdata {			## format rdata portion of RR string.
 	my $self = shift;
 
-	return '' unless defined $self->{longitude};
-	my ( $alt, @other ) = map $self->$_() . 'm', qw(altitude size hp vp);
-	my @rdata = ( $self->latitude, '', $self->longitude, '', $alt, join ' ', @other );
+	my ( $altitude, @precision ) = map { $self->$_() . 'm' } qw(altitude size hp vp);
+	my $precision = join ' ', @precision;
+	for ($precision) {
+		s/^1m 10000m 10m$//;
+		s/ 10000m 10m$//;
+		s/ 10m$//;
+	}
+	return ( $self->latitude, '', $self->longitude, '', $altitude, $precision );
 }
 
 
 sub _parse_rdata {			## populate RR from rdata in argument list
-	my $self = shift;
+	my ( $self, @argument ) = @_;
 
 	my @lat;
-	while ( scalar @_ ) {
-		my $this = shift;
+	while ( scalar @argument ) {
+		my $this = shift @argument;
 		push( @lat, $this );
 		last if $this =~ /[NSns]/;
 	}
 	$self->latitude(@lat);
 
 	my @long;
-	while ( scalar @_ ) {
-		my $this = shift;
+	while ( scalar @argument ) {
+		my $this = shift @argument;
 		push( @long, $this );
 		last if $this =~ /[EWew]/;
 	}
 	$self->longitude(@long);
 
 	foreach my $attr (qw(altitude size hp vp)) {
-		$self->$attr(shift) if scalar @_;
+		$self->$attr(@argument);
+		shift @argument;
 	}
-
+	return;
 }
 
 
@@ -78,67 +79,69 @@ sub _defaults {				## specify RR attribute default values
 	my $self = shift;
 
 	$self->{version} = 0;
-	$self->_parse_rdata( 0, 0, 0, 1, 10000, 10 );
+	$self->size(1);
+	$self->hp(10000);
+	$self->vp(10);
+	return;
 }
 
 
 sub latitude {
-	my $self = shift;
-	$self->{latitude} = _encode_lat(@_) if scalar @_;
-	return _decode_lat( $self->{latitude} ) if defined wantarray;
+	my ( $self, @value ) = @_;
+	$self->{latitude} = _encode_angle(@value) if scalar @value;
+	return _decode_angle( $self->{latitude} || return, 'N', 'S' );
 }
 
 
 sub longitude {
-	my $self = shift;
-	$self->{longitude} = _encode_lat(@_) if scalar @_;
-	return undef unless defined wantarray;
-	return _decode_lat( $self->{longitude} ) unless wantarray;
-	my @long = map { s/N/E/; s/S/W/; $_ } _decode_lat( $self->{longitude} );
+	my ( $self, @value ) = @_;
+	$self->{longitude} = _encode_angle(@value) if scalar @value;
+	return _decode_angle( $self->{longitude} || return, 'E', 'W' );
 }
 
 
 sub altitude {
-	my $self = shift;
-	$self->{altitude} = _encode_alt(shift) if scalar @_;
-	_decode_alt( $self->{altitude} ) if defined wantarray;
+	my ( $self, @value ) = @_;
+	$self->{altitude} = _encode_alt(@value) if scalar @value;
+	return _decode_alt( $self->{altitude} );
 }
 
 
 sub size {
-	my $self = shift;
-	$self->{size} = _encode_prec(shift) if scalar @_;
-	_decode_prec( $self->{size} ) if defined wantarray;
+	my ( $self, @value ) = @_;
+	$self->{size} = _encode_prec(@value) if scalar @value;
+	return _decode_prec( $self->{size} );
 }
 
 
 sub hp {
-	my $self = shift;
-	$self->{hp} = _encode_prec(shift) if scalar @_;
-	_decode_prec( $self->{hp} ) if defined wantarray;
+	my ( $self, @value ) = @_;
+	$self->{hp} = _encode_prec(@value) if scalar @value;
+	return _decode_prec( $self->{hp} );
 }
 
-sub horiz_pre { &hp; }						# uncoverable pod
+sub horiz_pre { return &hp; }					# uncoverable pod
 
 
 sub vp {
-	my $self = shift;
-	$self->{vp} = _encode_prec(shift) if scalar @_;
-	_decode_prec( $self->{vp} ) if defined wantarray;
+	my ( $self, @value ) = @_;
+	$self->{vp} = _encode_prec(@value) if scalar @value;
+	return _decode_prec( $self->{vp} );
 }
 
-sub vert_pre { &vp; }						# uncoverable pod
+sub vert_pre { return &vp; }					# uncoverable pod
 
 
 sub latlon {
-	my $self = shift;
-	my ( $lat, @lon ) = @_;
-	my @pair = scalar $self->latitude(@_), scalar $self->longitude(@lon);
+	my ( $self, @argument ) = @_;
+	my @lat = @argument;
+	my ( undef, @long ) = @argument;
+	return ( scalar $self->latitude(@lat), scalar $self->longitude(@long) );
 }
 
 
 sub version {
-	shift->{version};
+	return shift->{version};
 }
 
 
@@ -146,34 +149,35 @@ sub version {
 
 no integer;
 
-my $datum_alt = 10000000;
-my $datum_loc = 0x80000000;
+use constant ALTITUDE0 => 10000000;
+use constant ORDINATE0 => 0x80000000;
 
-sub _decode_lat {
-	my $msec = shift;
-	return int( 0.5 + ( $msec - $datum_loc ) / 0.36 ) / 10000000 unless wantarray;
+sub _decode_angle {
+	my ( $msec, $N, $S ) = @_;
+	return int( 0.5 + ( $msec - ORDINATE0 ) / 0.36 ) / 10000000 unless wantarray;
 	use integer;
-	my $abs = abs( $msec - $datum_loc );
+	my $abs = abs( $msec - ORDINATE0 );
 	my $deg = int( $abs / 3600000 );
 	my $min = int( $abs / 60000 ) % 60;
 	no integer;
 	my $sec = ( $abs % 60000 ) / 1000;
-	return ( $deg, $min, $sec, ( $msec < $datum_loc ? 'S' : 'N' ) );
+	return ( $deg, $min, $sec, ( $msec < ORDINATE0 ? $S : $N ) );
 }
 
 
-sub _encode_lat {
-	my @ang = scalar @_ > 1 ? (@_) : ( split /[\s\260'"]+/, shift );
+sub _encode_angle {
+	my @ang = @_;
+	@ang = split /[\s\260'"]+/, shift @ang unless scalar @ang > 1;
 	my $ang = ( 0 + shift @ang ) * 3600000;
 	my $neg = ( @ang ? pop @ang : '' ) =~ /[SWsw]/;
 	$ang += ( @ang ? shift @ang : 0 ) * 60000;
 	$ang += ( @ang ? shift @ang : 0 ) * 1000;
-	return int( 0.5 + ( $neg ? $datum_loc - $ang : $datum_loc + $ang ) );
+	return int( 0.5 + ( $neg ? ORDINATE0 - $ang : ORDINATE0 + $ang ) );
 }
 
 
 sub _decode_alt {
-	my $cm = (shift) - $datum_alt;
+	my $cm = ( shift || ALTITUDE0 ) - ALTITUDE0;
 	return 0.01 * $cm;
 }
 
@@ -181,27 +185,28 @@ sub _decode_alt {
 sub _encode_alt {
 	( my $argument = shift ) =~ s/[Mm]$//;
 	$argument += 0;
-	return int( 0.5 + $datum_alt + 100 * $argument );
+	return int( 0.5 + ALTITUDE0 + 100 * $argument );
 }
 
 
-my @power10 = ( 0.01, 0.1, 1, 1e1, 1e2, 1e3, 1e4, 1e5, 1e6, 1e7, 1e8, 1e99 );
+my @power10 = ( 0.01, 0.1, 1, 1e1, 1e2, 1e3, 1e4, 1e5, 1e6, 1e7, 1e8, 0, 0, 0, 0, 0 );
 
 sub _decode_prec {
-	my $argument = shift;
+	my $argument = shift || 0;
 	my $mantissa = $argument >> 4;
 	return $mantissa * $power10[$argument & 0x0F];
 }
 
 sub _encode_prec {
 	( my $argument = shift ) =~ s/[Mm]$//;
-	foreach my $exponent ( 0 .. 9 ) {
-		next unless $argument < $power10[1 + $exponent];
-		my $mantissa = int( 0.5 + $argument / $power10[$exponent] );
-		return ( $mantissa & 0xF ) << 4 | $exponent;
-	}
+	my $exponent = 0;
+	until ( $argument < $power10[1 + $exponent] ) { $exponent++ }
+	my $mantissa = int( 0.5 + $argument / $power10[$exponent] );
+	return ( $mantissa & 0xF ) << 4 | $exponent;
 }
 
+########################################
+
 
 1;
 __END__
@@ -209,8 +214,8 @@ __END__
 
 =head1 SYNOPSIS
 
-    use Net::DNS;
-    $rr = new Net::DNS::RR('name LOC latitude longitude altitude size hp vp');
+	use Net::DNS;
+	$rr = Net::DNS::RR->new('name LOC latitude longitude altitude size hp vp');
 
 =head1 DESCRIPTION
 
@@ -228,12 +233,12 @@ other unpredictable behaviour.
 
 =head2 latitude
 
-    $latitude = $rr->latitude;
-    ($deg, $min, $sec, $ns ) = $rr->latitude;
+	$latitude = $rr->latitude;
+	($deg, $min, $sec, $ns ) = $rr->latitude;
 
-    $rr->latitude( 42.357990 );
-    $rr->latitude( 42, 21, 28.764, 'N' );
-    $rr->latitude( '42 21 28.764 N' );
+	$rr->latitude( 42.357990 );
+	$rr->latitude( 42, 21, 28.764, 'N' );
+	$rr->latitude( '42 21 28.764 N' );
 
 When invoked in scalar context, latitude is returned in degrees,
 a negative ordinate being south of the equator.
@@ -247,12 +252,12 @@ or formatted string. Trailing zero values are optional.
 
 =head2 longitude
 
-    $longitude = $rr->longitude;
-    ($deg, $min, $sec, $ew ) = $rr->longitude;
+	$longitude = $rr->longitude;
+	($deg, $min, $sec, $ew ) = $rr->longitude;
 
-    $rr->longitude( -71.014338 );
-    $rr->longitude( 71, 0, 51.617, 'W' );
-    $rr->longitude( '71 0 51.617 W' );
+	$rr->longitude( -71.014338 );
+	$rr->longitude( 71, 0, 51.617, 'W' );
+	$rr->longitude( '71 0 51.617 W' );
 
 When invoked in scalar context, longitude is returned in degrees,
 a negative ordinate being west of the prime meridian.
@@ -263,43 +268,43 @@ as appropriate.
 
 =head2 altitude
 
-    $altitude = $rr->altitude;
+	$altitude = $rr->altitude;
 
 Represents altitude, in metres, relative to the WGS 84 reference
 spheroid used by GPS.
 
 =head2 size
 
-    $size = $rr->size;
+	$size = $rr->size;
 
 Represents the diameter, in metres, of a sphere enclosing the
 described entity.
 
 =head2 hp
 
-    $hp = $rr->hp;
+	$hp = $rr->hp;
 
 Represents the horizontal precision of the data expressed as the
 diameter, in metres, of the circle of error.
 
 =head2 vp
 
-    $vp = $rr->vp;
+	$vp = $rr->vp;
 
 Represents the vertical precision of the data expressed as the
 total spread, in metres, of the distribution of possible values.
 
 =head2 latlon
 
-    ($lat, $lon) = $rr->latlon;
-    $rr->latlon($lat, $lon);
+	($lat, $lon) = $rr->latlon;
+	$rr->latlon($lat, $lon);
 
 Representation of the latitude and longitude coordinate pair as
 signed floating-point degrees.
 
 =head2 version
 
-    $version = $rr->version;
+	$version = $rr->version;
 
 Version of LOC protocol.
 
@@ -319,7 +324,7 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 Permission to use, copy, modify, and distribute this software and its
 documentation for any purpose and without fee is hereby granted, provided
-that the above copyright notice appear in all copies and that both that
+that the original copyright notices appear in all copies and that both
 copyright notice and this permission notice appear in supporting
 documentation, and that the name of the author not be used in advertising
 or publicity pertaining to distribution of the software without specific
@@ -336,6 +341,7 @@ DEALINGS IN THE SOFTWARE.
 
 =head1 SEE ALSO
 
-L<perl>, L<Net::DNS>, L<Net::DNS::RR>, RFC1876
+L<perl> L<Net::DNS> L<Net::DNS::RR>
+L<RFC1876|https://iana.org/go/rfc1876>
 
 =cut
